#[non_exhaustive]pub enum Event<'a> {
DataOffer {
id: &'a ExtDataControlOfferV1,
},
Selection {
id: Option<&'a ExtDataControlOfferV1>,
},
Finished,
PrimarySelection {
id: Option<&'a ExtDataControlOfferV1>,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DataOffer
introduce a new ext_data_control_offer
The data_offer event introduces a new ext_data_control_offer object, which will subsequently be used in either the ext_data_control_device.selection event (for the regular clipboard selections) or the ext_data_control_device.primary_selection event (for the primary clipboard selections). Immediately following the ext_data_control_device.data_offer event, the new data_offer object will send out ext_data_control_offer.offer events to describe the MIME types it offers.
Fields
id: &'a ExtDataControlOfferV1Selection
advertise new selection
The selection event is sent out to notify the client of a new ext_data_control_offer for the selection for this device. The ext_data_control_device.data_offer and the ext_data_control_offer.offer events are sent out immediately before this event to introduce the data offer object. The selection event is sent to a client when a new selection is set. The ext_data_control_offer is valid until a new ext_data_control_offer or NULL is received. The client must destroy the previous selection ext_data_control_offer, if any, upon receiving this event. Regardless, the previous selection will be ignored once a new selection ext_data_control_offer is received.
The first selection event is sent upon binding the ext_data_control_device object.
Fields
id: Option<&'a ExtDataControlOfferV1>Finished
this data control is no longer valid
This data control object is no longer valid and should be destroyed by the client.
PrimarySelection
advertise new primary selection
The primary_selection event is sent out to notify the client of a new ext_data_control_offer for the primary selection for this device. The ext_data_control_device.data_offer and the ext_data_control_offer.offer events are sent out immediately before this event to introduce the data offer object. The primary_selection event is sent to a client when a new primary selection is set. The ext_data_control_offer is valid until a new ext_data_control_offer or NULL is received. The client must destroy the previous primary selection ext_data_control_offer, if any, upon receiving this event. Regardless, the previous primary selection will be ignored once a new primary selection ext_data_control_offer is received.
If the compositor supports primary selection, the first primary_selection event is sent upon binding the ext_data_control_device object.
Fields
id: Option<&'a ExtDataControlOfferV1>